==> dotnetify-5.2.0.tgz: package/README.md <==
<p align="center"><img width="400px" src="http://dotnetify.net/content/images/dotnetify-logo.png"></p>

![alt build](https://github.com/dsuryd/dotNetify/actions/workflows/build.yml/badge.svg)
[![npm version](https://badge.fury.io/js/dotnetify.svg)](https://badge.fury.io/js/dotnetify)
[![NuGet](https://img.shields.io/nuget/v/DotNetify.SignalR.svg?style=flat-square)](https://www.nuget.org/packages/DotNetify.SignalR/)

DotNetify is a free, open source project that lets you create real-time, reactive, cross-platform apps with [React](https://facebook.github.io/react/), [React Native](https://facebook.github.io/react-native/), [Vue](https://vuejs.org), [Knockout](http://knockoutjs.com) or [Blazor](https://dotnet.microsoft.com/apps/aspnet/web-apps/blazor) front-end on C# .NET back-end via WebSocket (SignalR).

## What's New

- **v5.0: Scale-out, Vue 3.x support** - [release notes](https://github.com/dsuryd/dotNetify/releases/tag/v5.0).
- v4.1: Async view model - [release notes](https://github.com/dsuryd/dotNetify/releases/tag/v4.1).
- v4.0: Typescript support - [release notes](https://github.com/dsuryd/dotNetify/releases/tag/v4.0).

## Features

- Simple and lightweight - no heavy client-side framework, no REST APIs.
- Reactive back-end MVVM architecture on ASP.NET server.
- Built-in real-time across WebSocket with SignalR.
- Support local (client-side only) and Web API modes.
- Full support for single-page apps, including deep-linked, nested routing and token-based authentication.
- Powerful back-end infrastructure, including dependency injection, WebSocket request/response pipelines, and modern tooling.

## Premium Features

- [**DotNetify-Observer**](https://www.dotnetify.net/core/dotnetify-observer): real-time connection visualization dashboard.
- [**DotNetify-LoadTester**](https://www.dotnetify.net/core/dotnetify-loadtester): performance testing tool for dotNetify apps.
- [**DotNetify-Testing**](https://www.dotnetify.net/core/dotnetify-testing): testing library for dotNetify apps.

## Documentation

Documentation and live demo can be found at [https://dotnetify.net](https://dotnetify.net).

[Usage with .NET Core 3.x](https://github.com/dsuryd/dotNetify/issues/159#issuecomment-547691063)

## Code Examples

- React example: [dotnetify-react-demo](https://github.com/dsuryd/dotnetify-react-demo).
- React Native example: [dotnetify-react-native-demo](https://github.com/dsuryd/dotnetify-react-native-demo).
- Other examples: [demo repo](https://github.com/dsuryd/dotNetify/tree/master/Demo).

## License

Licensed under the Apache License, Version 2.0.

## Contributing

All contribution is welcome: star this project, let others know about it, report issues, submit pull requests!

_Logo design by [area55git](https://github.com/area55git)._

==> dotnetify-5.4.0.tgz: package/README.md <==
<p align="center"><img width="400px" src="http://dotnetify.net/content/images/dotnetify-logo.png"></p>

![alt build](https://github.com/dsuryd/dotNetify/actions/workflows/build.yml/badge.svg)
[![npm version](https://badge.fury.io/js/dotnetify.svg)](https://badge.fury.io/js/dotnetify)
[![NuGet](https://img.shields.io/nuget/v/DotNetify.SignalR.svg?style=flat-square)](https://www.nuget.org/packages/DotNetify.SignalR/)

DotNetify is a free, open source project that lets you create real-time, reactive, cross-platform apps with [React](https://facebook.github.io/react/), [React Native](https://facebook.github.io/react-native/), [Vue](https://vuejs.org), [Knockout](http://knockoutjs.com) or [Blazor](https://dotnet.microsoft.com/apps/aspnet/web-apps/blazor) front-end on C# .NET back-end via WebSocket (SignalR).

## What's New

- **Minimal API** - [release notes](https://github.com/dsuryd/dotNetify/releases/tag/v5.3).
- Scale-out, Vue 3.x support - [release notes](https://github.com/dsuryd/dotNetify/releases/tag/v5.0).
- Async view model - [release notes](https://github.com/dsuryd/dotNetify/releases/tag/v4.1).

**DotNetify.Postgres: [Real-time Web Updates From Your PostgreSQL Database](https://dsuryd.github.io/dotNetify/realtime-postgres/)**

## Features

- Simple and lightweight - no heavy client-side framework, no REST APIs.
- Reactive back-end MVVM architecture on ASP.NET server.
- Built-in real-time across WebSocket with SignalR.
- Support local (client-side only) and Web API modes.
- Full support for single-page apps, including deep-linked, nested routing and token-based authentication.
- Powerful back-end infrastructure, including dependency injection, WebSocket request/response pipelines, and modern tooling.

## Premium Features

- [**DotNetify-Observer**](https://www.dotnetify.net/core/dotnetify-observer): real-time connection visualization dashboard.
- [**DotNetify-LoadTester**](https://www.dotnetify.net/core/dotnetify-loadtester): performance testing tool for dotNetify apps.
- [**DotNetify-Testing**](https://www.dotnetify.net/core/dotnetify-testing): testing library for dotNetify apps.

## Documentation

Documentation and live demo can be found at [https://dotnetify.net](https://dotnetify.net).

## Code Examples

- React example: [dotnetify-react-demo](https://github.com/dsuryd/dotnetify-react-demo).
- React Native example: [dotnetify-react-native-demo](https://github.com/dsuryd/dotnetify-react-native-demo).
- Other examples: [demo repo](https://github.com/dsuryd/dotNetify/tree/master/Demo).

## License

Licensed under the Apache License, Version 2.0.

## Contributing

All contribution is welcome: star this project, let others know about it, report issues, submit pull requests!

_Logo design by [area55git](https://github.com/area55git)._
